#
# spec file for package python-watchfiles
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-watchfiles
Version:        0.24.0
Release:        1.2
Summary:        File watching and code reload in python
License:        MIT
URL:            https://github.com/samuelcolvin/watchfiles
Source0:        https://github.com/samuelcolvin/watchfiles/archive/refs/tags/v%{version}.tar.gz#/watchfiles-%{version}-gh.tar.gz
Source1:        vendor.tar.xz
# gh#samuelcolvin/watchfiles#254
BuildRequires:  %{python_module anyio >= 3.0.0 with %python-anyio < 4}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module maturin >= 0.14.16}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-anyio >= 3.0.0 with python-anyio < 4)
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION test
BuildRequires:  %{python_module dirty-equals}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-pretty}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A package for file watching and code reload in python.

This package was previously named "watchgod".

%prep
%autosetup -p1 -n watchfiles-%{version} -a1
# Need to replace version because we build from github archive
sed -i 's/version = "0.0.0"/version = "%{version}"/' Cargo.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/watchfiles
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv watchfiles watchfiles.movedaway
%pytest_arch

%post
%python_install_alternative watchfiles

%postun
%python_uninstall_alternative watchfiles

%files %{python_files}
%license LICENSE
%doc README.md docs/*
%python_alternative %{_bindir}/watchfiles
%{python_sitearch}/watchfiles
%{python_sitearch}/watchfiles-%{version}*-info

%changelog
* Wed Sep 25 2024 ecsos <ecsos@opensuse.org>
- Update to 0.24.0:
  - drop PyPy 3.8 by @samuelcolvin in #293
  - Update Python version in index.md by @kjaymiller in #296
  - return "file deleted" instead of raising an exception,
    fix #282 by @samuelcolvin in #301
- Changes from 0.23.0:
  - Fix typo in watch doctstring by @kwentine in #280
  - Bump up PyO3 to 0.22.2 by @FlickerSoul in #287
  - Updates to GitHub Actions by @gaby in #274
  - Update mkdocstring python handler option key by @kwentine in
    [#281]
  - Bump requests from 2.31.0 to 2.32.0 in /requirements by
    @dependabot in #278
  - Bump urllib3 from 2.2.1 to 2.2.2 in /requirements by
    @dependabot in #283
  - Bump certifi from 2024.2.2 to 2024.7.4 in /requirements by
    @dependabot in #285
  - Add support for Python 3.13 by @hugovk in #277
  - remove watchfiles from ignore directory list by @CharlesFr in
    [#249]
  - fix windows build by @samuelcolvin in #291
  - Full CI build by default by @samuelcolvin in #290
  - use intern! in rust code by @samuelcolvin in #292
- Add %%{?sle15_python_module_pythons}
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 0.22.0:
  * fix `list-pypi-files` CI task
  * pip show wrong homepage
  * Update PyO3
  * really drop python<=3.7 support
  * uprev pyo3 and minimum rust version
  * drop black and isort
  * pre-commit block main - related to `notify` update
  * Bump idna from 3.3 to 3.7 in /requirements
  * uprev linting, testing and docs requirements
* Fri Feb  9 2024 Ben Greiner <code@bnavigator.de>
- Pin to anyio < 4: gh#samuelcolvin/watchfiles#254
- Refresh cargo vendoring
* Sun Nov 19 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to 0.21.0:
  * Add Python 3.12 support, drop Python 3.7 support by @gi0baro in
    [#248]
- additional changes from 0.20.0:
  * Bump pymdown-extensions from 9.5 to 10.0 in /requirements by
    @dependabot in #229
  * Bump pygments from 2.13.0 to 2.15.0 in /requirements by
    @dependabot in #237
  * Allow maturin 1.x by @heirecka in #233
  * Fix: Memory leak of PyO3 by @koseki2580 in #240
  * Improve debug by @samuelcolvin in #242
  * add grace period during which file changes are ignored by
    @samuelcolvin in #243
  * Add ignore_permission_denied option by @aminalaee in #224
  * Catch SIGTERM and kill running process before exitting by
    @samuelcolvin in #244
- refresh vendor.tar.xz
- drop cargo_config.patch: included in vendor archive now
- build one wheel per python flavor: a single wheel for all flavor
  does not work anymore
- set the minimum python version to 3.8
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Update to v0.19.0
  * Better error on OS watcher limit by @samuelcolvin in #208
  * Switch flake8->ruff by @TheoBabilon in #212
  * Simplify Change.raw_str() by @davidbrochart in #211
  * Upgrade maturin to 0.14 by @messense in #214
  * Fix bug in RustNotify causing RuntimeError: Already borrowed on
    exit/signal by @vrslev in #221
  * Update pyo3 to 0.18.2 by @messense in #222
- Release v0.18.1
  * uprev pyo3, relax anyio constraint by @samuelcolvin in #203
  * switch pytest-sugar -> pytest-pretty by @samuelcolvin in #204
- Release v0.18.0
  * Force polling on WSL #194
  * increase default polling delay to 300ms #196
- Release v0.17.0
  * uprev notify to 5.0.0-pre.16, #182
  * Add option to disable recursion by @bvanelli in #183
  * upgrade to notify 5.0.0, #184
  * Lock all requirements, #185
- Release v0.16.0
  * make RustNotify a context manager and kill the thread on exit
    [#164]
  * Support WATCHFILES_FORCE_POLLING env var #170
  * fallback to poll watcher on OS Error 38 #172
  * --verbose argument and improve bug template #174
- Switch from PyPI sdist to github archive: docs missing, required
  for tests
* Mon Jul 18 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile fo v0.15.0
- Replaces python-watchgod
- Required by python-uvicorn
